%%
%% Author: Michal Houda
%% E-mail: houda at ef dot jcu dot cz
%%
%% Modified by: Stanislav Tvrz
%% E-mail: tvrz at mail dot muni dot cz
%%
%% Description: this is a LaTeX class for contributions to the 
%%   Proceedings of the International Conference on 
%%   Mathematical Methods in Economics
%% 
%% This program may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{mmeproc}
  [2012/06/13 v1.1 MME Proceedings class for LaTeX 2e]

%%
%% Using article class, no additional options allowed
%%
\LoadClass[10pt,a4paper]{article}
%% Some preloaded packages
\RequirePackage{geometry}       % page dimensions
\RequirePackage{graphicx}       % including graphic files
\RequirePackage{amsmath,amsthm,amssymb}  % advanced mathematics
\RequirePackage{enumitem}       % modified enumerate environment
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                    PAGE DIMENSIONS AND FORMATTING                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% (2.5cm margins on both sides regardless of the paper size)
%%
\geometry{%
  a4paper,twoside,
  top=25mm,headsep=17pt,
  bottom=25mm,footskip=13.5mm,
  left=25mm, % inner margin
  right=25mm % outer margin
}
\parskip=6pt plus 1pt
%%
%% Page numbering
%% The command \startpageno sets the page number to the specified value
%%
%\newcommand\startpageno[1]{\c@page=#1}
%% but this will be used only in production version of the proceedings
\pagestyle{empty}
%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             TITLE PAGE                                %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%
\def\cleartitleinfo{\gdef\@author{No Author Given}%
                   \gdef\@title{No Title Given}%
                   \gdef\@institute{No Institute Given}%
                   \gdef\@thanks{}%
                   \gdef\@keywords{No Keyword Given}%
                   \gdef\@amssubjclass{}%
                   \gdef\@jelsubjclass{}%
}
\AtBeginDocument{\cleartitleinfo}
%%
%% Author information
%%
\def\mmeproc@authors{
  \vskip 1.5em%
  {\def\and{\mmeproc@and@author}
    \large \@author\footnote{%
      \@institute
      \if:\@email:\else, \@email\fi
    }\vskip 6pt%
}}
\def\mmeproc@and@author{%     % Author name is here already typeset, 
  \footnote{%
    {\@institute\if:\@email:\else, \@email\fi}\relax
  } ,
}%   % the next author

%%
%% Other titlepage information
%%
\def\email#1{\gdef\@email{#1}}
\def\institute#1{\gdef\@institute{#1}}%
\def\keywords#1{\gdef\@keywords{#1}}%
\def\amssubjclass#1{\gdef\@amssubjclass{%
  \textbf{AMS classification:} #1}}%
\def\jelsubjclass#1{\gdef\@jelsubjclass{%
  \textbf{JEL classification:} #1}}%
%%
%% Changes to the original LaTeX abstract environment
%% This does not work with the titlepage and twocolumn options!
%%
\newbox\mmeproc@abstractbox
\renewenvironment{abstract}{%
  \ifx\maketitle\relax
    \ClassWarning{mmeproc}{Abstract should precede
      \protect\maketitle\space in mmeproc class}%
  \fi
  \global\setbox\mmeproc@abstractbox=\hbox to 12cm
  \bgroup\begin{minipage}{12cm}\parskip=6pt
  \textbf{\abstractname.}
}{\end{minipage}\egroup}
%%
%% Making titlepage
%%
\def\@maketitle{%
  \def\thefootnote{\@arabic\c@footnote}
  \newpage
  \null
  \vskip 2em%
  \begin{center}
    {\LARGE\bfseries \@title \par}%
    \mmeproc@authors\par
    \begin{minipage}{12cm}
      \parindent=\z@\parskip=6pt
      \box\mmeproc@abstractbox\par

    {\bfseries\noindent Keywords:} \@keywords\par
    \@jelsubjclass\parskip\z@\par
    \@amssubjclass\par
    \end{minipage}
  \end{center}
\pagestyle{empty}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                           HEADINGS                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% only section and subsections are numbered within an article
%%
\setcounter{secnumdepth}{2}
%%
%% spacing shifted section <- subsection <- subsubsection
%%
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-3.25ex \@plus -1ex \@minus -.2ex}%
                                   {1.5ex \@plus.2ex}%
                                   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                              LISTS                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%  Modified enumerate and itemize environments

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             THEOREMS                                  %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Theorems are defined using amsthm style file. 
%%
%
\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{proposition}[theorem]{Proposition}
%
\theoremstyle{definition}
\newtheorem{definition}{Definition}
\newtheorem{example}{Example}
\newtheorem{remark}{Remark}
%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             OTHER                                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Table stretching
\renewcommand\arraystretch{1.2}
%%
%% Caption style modification (bold caption headers).
%%
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\bf #1} #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
%%
%%
%%
%% Environment article: setting starting page number
%% only for the production version of the proceedings
%%
\newenvironment{article}[1][1]{%
  \startpageno{#1}         % the starting page number
  \maketitle
}{\relax}
\def\acknowledgements{\section*{Acknowledgements}}
%%
%% modification of \@makecol (see original version in latex.ltx) 
%% -- the footnote is `vfilled'
%%
\gdef \@makecol {%
   \ifvoid\footins
     \setbox\@outputbox \box\@cclv
   \else
     \setbox\@outputbox \vbox {%
       \boxmaxdepth \@maxdepth
       \@tempdima\dp\@cclv
       \unvbox \@cclv
       \vskip-\@tempdima
       \vskip \skip\footins
       \vfill                   % <<--------- inserted
       \color@begingroup
         \normalcolor
         \footnoterule
         \unvbox \footins
       \color@endgroup
       }%
   \fi
   \xdef\@freelist{\@freelist\@midlist}%
   \global \let \@midlist \@empty
   \@combinefloats
   \ifvbox\@kludgeins
     \@makespecialcolbox
   \else
     \setbox\@outputbox \vbox to\@colht {%
       \@texttop
       \dimen@ \dp\@outputbox
       \unvbox \@outputbox
       \vskip -\dimen@
       \@textbottom
       }%
   \fi
   \global \maxdepth \@maxdepth
}

\endinput
%%
%% End of file `cesbull.cls'.
